@@ -330,8 +330,9 @@ def assert_coverage_warnings(
     """
     assert msgs     # don't call this without some messages.
     warns = [w for w in warns if issubclass(w.category, CoverageWarning)]
-    assert len(warns) == len(msgs)
-    for actual, expected in zip((cast(Warning, w.message).args[0] for w in warns), msgs):
+    actuals = [cast(Warning, w.message).args[0] for w in warns]
+    assert len(msgs) == len(actuals)
+    for expected, actual in zip(msgs, actuals):
         if hasattr(expected, "search"):
             assert expected.search(actual), f"{actual!r} didn't match {expected!r}"
         else:
@@ -396,3 +397,8 @@ class DebugControlString(DebugControl):
     def get_output(self) -> str:
         """Get the output text from the `DebugControl`."""
         return self.io.getvalue()
+
+
+def without_color(text: str) -> str:
+    """Remove ANSI color-setting escape sequences."""
+    return re.sub(r"\033\[[\d;]+m", "", text)
