@@ -7,7 +7,6 @@ from __future__ import annotations
 
 import pytest
 
-from tests import testenv
 from tests.coveragetest import CoverageTest
 from tests.helpers import assert_count_equal, xfail_pypy38
 
@@ -1308,7 +1307,6 @@ class YieldTest(CoverageTest):
             arcz=".1 19 9.  .2 23 34 45 56 63 37 7.",
         )
 
-    @pytest.mark.xfail(testenv.SYS_MON, reason="TODO: fix this for sys.monitoring")
     def test_abandoned_yield(self) -> None:
         # https://github.com/nedbat/coveragepy/issues/440
         self.check_coverage("""\
@@ -1651,7 +1649,6 @@ class MiscArcTest(CoverageTest):
         self.check_coverage(code, arcs=[(-1, 1), (1, 2*n+4), (2*n+4, -1)])
         assert self.stdout() == f"{n}\n"
 
-    @pytest.mark.xfail(testenv.SYS_MON, reason="TODO: fix this for sys.monitoring")
     def test_partial_generators(self) -> None:
         # https://github.com/nedbat/coveragepy/issues/475
         # Line 2 is executed completely.
@@ -1854,7 +1851,11 @@ class LambdaArcTest(CoverageTest):
         )
 
 
-xfail_eventlet_670 = pytest.mark.xfail(
+# This had been a failure on Mac 3.9, but it started passing on GitHub
+# actions (running macOS 12) but still failed on my laptop (macOS 14).
+# I don't understand why it failed, I don't understand why it passed,
+# so just skip the whole thing.
+skip_eventlet_670 = pytest.mark.skipif(
     env.PYVERSION[:2] == (3, 9) and env.CPYTHON and env.OSX,
     reason="Avoid an eventlet bug on Mac 3.9: eventlet#670",
     # https://github.com/eventlet/eventlet/issues/670
@@ -1864,7 +1865,7 @@ xfail_eventlet_670 = pytest.mark.xfail(
 class AsyncTest(CoverageTest):
     """Tests of the new async and await keywords in Python 3.5"""
 
-    @xfail_eventlet_670
+    @skip_eventlet_670
     def test_async(self) -> None:
         self.check_coverage("""\
             import asyncio
@@ -1891,7 +1892,7 @@ class AsyncTest(CoverageTest):
         )
         assert self.stdout() == "Compute 1 + 2 ...\n1 + 2 = 3\n"
 
-    @xfail_eventlet_670
+    @skip_eventlet_670
     def test_async_for(self) -> None:
         self.check_coverage("""\
             import asyncio
@@ -1988,7 +1989,7 @@ class AsyncTest(CoverageTest):
 
     # https://github.com/nedbat/coveragepy/issues/1176
     # https://bugs.python.org/issue44622
-    @xfail_eventlet_670
+    @skip_eventlet_670
     def test_bug_1176(self) -> None:
         self.check_coverage("""\
             import asyncio
