@@ -27,6 +27,7 @@ import coverage.html
 from coverage.report_core import get_analysis_to_report
 from coverage.types import TLineNo, TMorf
 
+from tests import testenv
 from tests.coveragetest import CoverageTest, TESTS_DIR
 from tests.goldtest import gold_path
 from tests.goldtest import compare, contains, contains_rx, doesnt_contain, contains_any
@@ -570,14 +571,14 @@ class HtmlTest(HtmlTestHelpers, CoverageTest):
 
     def make_main_and_not_covered(self) -> None:
         """Helper to create files for skip_covered scenarios."""
-        self.make_file("main_file.py", """
+        self.make_file("main_file.py", """\
             import not_covered
 
             def normal():
                 print("z")
             normal()
         """)
-        self.make_file("not_covered.py", """
+        self.make_file("not_covered.py", """\
             def not_covered():
                 print("n")
         """)
@@ -607,7 +608,7 @@ class HtmlTest(HtmlTestHelpers, CoverageTest):
         self.assert_exists("htmlcov/not_covered_py.html")
 
     def test_report_skip_covered_100(self) -> None:
-        self.make_file("main_file.py", """
+        self.make_file("main_file.py", """\
             def normal():
                 print("z")
             normal()
@@ -619,7 +620,7 @@ class HtmlTest(HtmlTestHelpers, CoverageTest):
     def make_init_and_main(self) -> None:
         """Helper to create files for skip_empty scenarios."""
         self.make_file("submodule/__init__.py", "")
-        self.make_file("main_file.py", """
+        self.make_file("main_file.py", """\
             import submodule
 
             def normal():
@@ -1135,6 +1136,7 @@ assert len(math) == 18
         assert expected % os.sep in index
 
 
+@pytest.mark.skipif(not testenv.DYN_CONTEXTS, reason="No dynamic contexts with this core.")
 class HtmlWithContextsTest(HtmlTestHelpers, CoverageTest):
     """Tests of the HTML reports with shown contexts."""
 
